@@ -17,13 +17,13 @@
 #' \code{base} package.
 #'
 #' @inheritParams base::cbind
-#' @seealso \code{\link[base]{cbind}}, \code{\link[base]{rbind}}, 
+#' @seealso \code{\link[base:cbind]{cbind}}, \code{\link[base:cbind]{rbind}}, 
 #' \code{\link{cbind.mids}}, \code{\link{rbind.mids}}
 #' @keywords internal
 #' @export
 cbind <- function (...) {
   if (is.null(attr(list(...)[[1]], "class"))) return(base::cbind(...))
-  if (attr(list(...)[[1]], "class") == "mids") return(cbind.mids(...))
+  if ("mids" %in% attr(list(...)[[1]], "class")) return(cbind.mids(...))
   else return(base::cbind(...))
 }
 
@@ -31,6 +31,6 @@ cbind <- function (...) {
 #' @export
 rbind <- function (...) {
   if (is.null(attr(list(...)[[1]], "class"))) return(base::rbind(...))
-  if (attr(list(...)[[1]], "class") == "mids") return(rbind.mids(...))
+  if ("mids" %in% attr(list(...)[[1]], "class")) return(rbind.mids(...))
   else return(base::rbind(...))
 }
